	<bodytext>
{{header}}
use strict;

{{main}}
{{constructor}}
{{methods}}


{{footer}}
</bodytext>
	<title>Skeleton Program Template</title>
	<description>Template used in generating OO modules</description>
