use v6;


say "hello there";


__END__

=head1 NAME

 - 

=head1 SYNOPSIS

use ;

=head1 DESCRIPTION



=head1 METHODS

=over


=back

=head1 AUTHOR

Nigel Hamilton <nigel@turbo10.com>

=head1 SEE ALSO

